@@ -45,7 +45,6 @@
 
 #include <sys/types.h>
 #include <sys/time.h>
-#include <sys/select.h>
 #include <limits.h>
 
 #include <X11/Xatom.h>
@@ -74,9 +73,8 @@ winProcessXEventsTimeout(HWND hwnd, Window iWindow, Display * pDisplay,
     int iConnNumber;
     struct timeval tv;
     int iReturn;
-    DWORD dwStopTime = GetTickCount() + iTimeoutSec * 1000;
 
-    winDebug("winProcessXEventsTimeout () - pumping X events for %d seconds\n",
+    winDebug("winProcessXEventsTimeout () - pumping X events, timeout %d seconds\n",
              iTimeoutSec);
 
     /* Get our connection number */
@@ -105,11 +103,9 @@ winProcessXEventsTimeout(HWND hwnd, Window iWindow, Display * pDisplay,
         FD_SET(iConnNumber, &fdsRead);
 
         /* Adjust timeout */
-        remainingTime = dwStopTime - GetTickCount();
+        remainingTime = iTimeoutSec * 1000;
         tv.tv_sec = remainingTime / 1000;
         tv.tv_usec = (remainingTime % 1000) * 1000;
-        winDebug("winProcessXEventsTimeout () - %ld milliseconds left\n",
-                 remainingTime);
 
         /* Break out if no time left */
         if (remainingTime <= 0)
@@ -149,11 +145,6 @@ winClipboardWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
     static ClipboardAtoms *atoms;
     static Bool fRunning;
 
-#if CYGDEBUG
-    winDebugWin32Message("winClipboardWindowProc", hwnd, message, wParam,
-                         lParam);
-#endif
-
     /* Branch on message type */
     switch (message) {
     case WM_DESTROY:
@@ -219,9 +210,9 @@ winClipboardWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 
     case WM_CHANGECBCHAIN:
     {
-        winDebug("winClipboardWindowProc - WM_CHANGECBCHAIN: wParam(%x) "
-                 "lParam(%x) s_hwndNextViewer(%p)\n",
-                 (int)wParam, (int)lParam, s_hwndNextViewer);
+        winDebug("winClipboardWindowProc - WM_CHANGECBCHAIN: wParam(%p) "
+                 "lParam(%p) s_hwndNextViewer(%p)\n",
+                 (HWND)wParam, (HWND)lParam, s_hwndNextViewer);
 
         if ((HWND) wParam == s_hwndNextViewer) {
             s_hwndNextViewer = (HWND) lParam;
@@ -363,36 +354,6 @@ winClipboardWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
                      "Clipboard does not contain CF_TEXT nor "
                      "CF_UNICODETEXT.\n");
 
-            winDebug("winClipboardWindowProc: %d formats\n",
-                     CountClipboardFormats());
-
-            if (OpenClipboard(hwnd)) {
-                unsigned int format = 0;
-
-                do {
-                    format = EnumClipboardFormats(format);
-                    if (GetLastError() != ERROR_SUCCESS) {
-                        winDebug
-                            ("winClipboardWindowProc: EnumClipboardFormats failed %x\n",
-                             GetLastError());
-                    }
-                    if (format > 0xc000) {
-                        char buff[256];
-
-                        GetClipboardFormatName(format, buff, 256);
-                        winDebug("winClipboardWindowProc: %d %s\n", format,
-                                 buff);
-                    }
-                    else if (format > 0)
-                        winDebug("winClipboardWindowProc: %d\n", format);
-                } while (format != 0);
-                CloseClipboard();
-            }
-            else {
-                winDebug
-                    ("WindowProc: could not open clipboard to enumerate formats\n");
-            }
-
             /*
              * We need to make sure that the X Server has processed
              * previous XSetSelectionOwner messages.
@@ -405,7 +366,7 @@ winClipboardWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
             iReturn = XGetSelectionOwner(pDisplay, XA_PRIMARY);
             if (iReturn == iWindow) {
                 winDebug("winClipboardWindowProc - WM_DRAWCLIPBOARD - "
-                         "PRIMARY selection is owned by us, releasing\n");
+                         "PRIMARY selection is owned by us.\n");
                 XSetSelectionOwner(pDisplay, XA_PRIMARY, None, CurrentTime);
             }
             else if (BadWindow == iReturn || BadAtom == iReturn)
@@ -530,6 +491,9 @@ winClipboardWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 
         /* Process X events */
         data.fUseUnicode = fConvertToUnicode;
+        data.incr = NULL;
+        data.incrsize = 0;
+
         iReturn = winProcessXEventsTimeout(hwnd,
                                            iWindow,
                                            pDisplay,
@@ -539,7 +503,7 @@ winClipboardWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 
         if (WIN_XEVENTS_NOTIFY_TARGETS != iReturn) {
             ErrorF
-                ("winClipboardWindowProc - failed waiting for WIN_XEVENTS_NOTIFY_TARGETS\n");
+                ("winClipboardWindowProc - timed out waiting for WIN_XEVENTS_NOTIFY_TARGETS\n");
             goto fake_paste;
         }
 
@@ -553,10 +517,10 @@ winClipboardWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 
             struct target_priority target_priority_table[] =
                 {
-                    { atoms->atomCompoundText, 0 },
 #ifdef X_HAVE_UTF8_STRING
-                    { atoms->atomUTF8String,   1 },
+                    { atoms->atomUTF8String,   0 },
 #endif
+                    { atoms->atomCompoundText, 1 },
                     { XA_STRING,               2 },
                 };
 
