@@ -1116,7 +1116,6 @@ winMultiWindowWMProc(void *pArg)
                -- independently, the WM_TAKE_FOCUS protocol determines whether
                the WM should send a WM_TAKE_FOCUS ClientMessage.
             */
-            if (pNode->msg.iWindow)
             {
               Bool neverFocus = FALSE;
               xcb_get_property_cookie_t cookie;
@@ -1130,7 +1129,7 @@ winMultiWindowWMProc(void *pArg)
               }
 
               if (!neverFocus)
-                xcb_set_input_focus(pWMInfo->conn, XCB_INPUT_FOCUS_PARENT,
+                xcb_set_input_focus(pWMInfo->conn, XCB_INPUT_FOCUS_POINTER_ROOT,
                                     pNode->msg.iWindow, XCB_CURRENT_TIME);
 
               if (IsWmProtocolAvailable(pWMInfo,
@@ -1140,13 +1139,6 @@ winMultiWindowWMProc(void *pArg)
                              pNode->msg.iWindow,
                              pWMInfo->atmWmProtos, pWMInfo->atmWmTakeFocus);
 
-            }
-            else
-            /* Set the input focus to none */
-            {
-              xcb_set_input_focus(pWMInfo->conn, XCB_INPUT_FOCUS_NONE,
-                                  XCB_INPUT_FOCUS_NONE, XCB_CURRENT_TIME);
-
             }
             break;
 
